<?php
/**
 * The template for displaying the header
 *
 * Displays all of the head element and everything up until the "site-content" div.
 *
 * 
 * @package Indira
 * @since Indira 1.0
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js">
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">
	<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
	<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
	<?php endif; ?>
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
	<?php if ( get_header_image() ) : ?>
		<?php
			/**
			 * Filter the default indira custom header sizes attribute.
			 *
			 * @since Indira 1.0
			 *
			 * @param string $custom_header_sizes sizes attribute
			 * for Custom Header. Default '(max-width: 709px) 85vw,
			 * (max-width: 909px) 81vw, (max-width: 1362px) 88vw, 1200px'.
			 */
			$custom_header_sizes = apply_filters( 'indira_custom_header_sizes', '(max-width: 709px) 85vw, (max-width: 909px) 81vw, (max-width: 1362px) 88vw, 1200px' );
		?>
		<div class="header-image">
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
				<img src="<?php header_image(); ?>" srcset="<?php echo esc_attr( wp_get_attachment_image_srcset( get_custom_header()->attachment_id ) ); ?>" sizes="<?php echo esc_attr( $custom_header_sizes ); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>">
			</a>
		</div><!-- .header-image -->
	<?php endif; // End header image check. ?>

<div id="page" class="site">
	<div class="site-inner">
		<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'indira' ); ?></a>

		<header id="masthead" class="site-header" >
			<div class="site-header-main">
				<div class="site-branding" itemscope itemtype="http://schema.org/Organization">
					<?php indira_the_custom_logo(); ?>

					<?php if ( is_front_page() && is_home() ) : ?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
					<?php else : ?>
						<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
					<?php endif;

					$description = get_bloginfo( 'description', 'display' );
					if ( $description || is_customize_preview() ) : ?>
						<p class="site-description"><?php echo esc_html( $description ); ?></p>
					<?php endif; ?>
				</div><!-- .site-branding -->

				<?php if ( has_nav_menu( 'primary' ) || has_nav_menu( 'social' ) ) : ?>
					<button id="menu-toggle" class="menu-toggle"><?php echo indira_svg_icon('menu'); ?><span class="screen-reader-text"><?php esc_html_e( 'Menu', 'indira' ); ?></span></button>

					<div id="site-header-menu" class="site-header-menu">
						<?php if ( has_nav_menu( 'primary' ) ) : ?>
							<nav id="site-navigation" class="main-navigation" aria-label="<?php esc_attr_e( 'Primary Menu', 'indira' ); ?>">
								<?php
									wp_nav_menu( array(
										'theme_location' => 'primary',
										'menu_class'     => 'primary-menu',
									 ) );
								?>
							</nav><!-- .main-navigation -->
						<?php endif; ?>

						<div id="site-search" class="site-search">
							<button id="search-toggle" class="search-toggle"><span class="screen-reader-text"><?php esc_html_e('Search', 'indira'); ?></span><span class="toggled-icon"><?php echo indira_svg_icon('search'); ?></span><span class="untoggled-icon"><?php echo indira_svg_icon('close'); ?></span></button>
							<?php get_search_form(); ?>
						</div>

					</div><!-- .site-header-menu -->
				<?php endif; ?>
			</div><!-- .site-header-main --> 

		</header><!-- .site-header -->

		<div id="content" class="site-content">
